@@ -50,7 +50,7 @@ def preprocessing_training_common(df, config, model_type, mapping_dicts=None, im
           )
 
     #creation and application of the dictionaries
-    if mapping_dicts:
+    if mapping_dicts is None:
         logger.info("No mapping dicts present, creating them")
         mapping_dicts = {}
         mx_prob_dictionary, mx_bv_dictionary = DEutils.create_class_dictionaries(df, "MXType")
